@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2008  NTT DATA CORPORATION
  *
- * Version: 1.6.0   2008/04/01
+ * Version: 1.6.4   2008/09/03
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -31,6 +31,8 @@
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 5, 0)
 #include <linux/kmod.h>
 #include <asm/hardirq.h>
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 9)
+#include <asm/hardirq.h>
 #else
 #include <linux/hardirq.h>
 #endif
@@ -56,10 +58,9 @@ extern asmlinkage long sys_getppid(void);
 #endif
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 19)
-typedef _Bool bool;
+#define bool _Bool
 #endif
 
-
 #ifndef KERN_CONT
 #define KERN_CONT ""
 #endif
@@ -80,13 +81,11 @@ typedef _Bool bool;
 #endif
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 14)
-static inline void *kzalloc(int size, int flags)
-{
-	void *p = kmalloc(size, flags);
-	if (p)
-		memset(p, 0, size);
-	return p;
-}
+#define kzalloc(size, flags) ({						\
+			void *ret = kmalloc((size), (flags));		\
+			if (ret)					\
+				memset(ret, 0, (size));			\
+			ret; })
 #endif
 
 /*
@@ -261,7 +260,7 @@ struct address_group_entry {
 struct path_info_with_data {
 	/* Keep "head" first, for this pointer is passed to ccs_free(). */
 	struct path_info head;
-	char bariier1[16]; /* Safeguard for overrun. */
+	char barrier1[16]; /* Safeguard for overrun. */
 	char body[CCS_MAX_PATHNAME_LEN];
 	char barrier2[16]; /* Safeguard for overrun. */
 };
@@ -298,7 +297,7 @@ struct domain_info {
 	u8 profile;        /* Profile number to use. */
 	u8 is_deleted;     /* Delete flag.           */
 	bool quota_warned; /* Quota warnning flag.   */
-	/* DOMAIN_FLAGS_IGNORE_*. Use ccs_set_domain_flag() to modify. */
+	/* DOMAIN_FLAGS_*. Use ccs_set_domain_flag() to modify. */
 	u8 flags;
 };
 
@@ -309,6 +308,13 @@ struct domain_info {
 #define DOMAIN_FLAGS_IGNORE_GLOBAL_ALLOW_READ 1
 /* Ignore "allow_env" directive in exception policy.  */
 #define DOMAIN_FLAGS_IGNORE_GLOBAL_ALLOW_ENV  2
+/*
+ * This domain was unable to create a new domain at ccs_find_next_domain()
+ * because the name of the domain to be created was too long or
+ * it could not allocate memory.
+ * More than one process continued execve() without domain transition.
+ */
+#define DOMAIN_FLAGS_TRANSITION_FAILED        4
 
 /*
  * Structure for "execute_handler" and "denied_execute_handler" directive.
@@ -502,9 +508,8 @@ struct ip_network_acl_record {
 #define CCS_TOMOYO_MAX_GRANT_LOG                12
 #define CCS_TOMOYO_MAX_REJECT_LOG               13
 #define CCS_TOMOYO_VERBOSE                      14
-#define CCS_ALLOW_ENFORCE_GRACE                 15
-#define CCS_SLEEP_PERIOD                        16  /* profile.conf       */
-#define CCS_MAX_CONTROL_INDEX                   17
+#define CCS_SLEEP_PERIOD                        15  /* profile.conf       */
+#define CCS_MAX_CONTROL_INDEX                   16
 
 /* Index numbers for updates counter. */
 #define CCS_UPDATES_COUNTER_SYSTEM_POLICY    0
@@ -641,8 +646,8 @@ int ccs_add_domain_acl(struct domain_info *domain, struct acl_info *acl);
 /* Check whether there is space for audit logs. */
 int ccs_can_save_audit_log(const bool is_granted);
 /* Ask supervisor's opinion. */
-int ccs_check_supervisor(const char *fmt, ...)
-	__attribute__ ((format(printf, 1, 2)));
+int ccs_check_supervisor(struct linux_binprm *bprm, const char *fmt, ...)
+	__attribute__ ((format(printf, 2, 3)));
 /* Close /proc/ccs/ interface. */
 int ccs_close_control(struct file *file);
 /* Delete an ACL entry from domain's ACL list. */
@@ -742,7 +747,7 @@ struct domain_info *ccs_find_or_assign_new_domain(const char *domainname,
 						  const u8 profile);
 /* Undelete a domain. */
 struct domain_info *ccs_undelete_domain(const char *domainname);
-/* Write a grant log. */
+/* Check mode for specified capability. */
 u8 ccs_check_capability_flags(const u8 index);
 /* Check mode for specified functionality. */
 unsigned int ccs_check_flags(const u8 index);
@@ -776,13 +781,13 @@ static inline bool ccs_pathcmp(const struct path_info *a,
 /* Get type of an ACL entry. */
 static inline u8 ccs_acl_type1(struct acl_info *ptr)
 {
-	return (ptr->type & ~(ACL_DELETED | ACL_WITH_CONDITION));
+	return ptr->type & ~(ACL_DELETED | ACL_WITH_CONDITION);
 }
 
 /* Get type of an ACL entry. */
 static inline u8 ccs_acl_type2(struct acl_info *ptr)
 {
-	return (ptr->type & ~ACL_WITH_CONDITION);
+	return ptr->type & ~ACL_WITH_CONDITION;
 }
 
 /* A linked list of domains. */
@@ -796,4 +801,46 @@ extern struct domain_info KERNEL_DOMAIN;
 /* Exclusive lock for updating domain policy. */
 extern struct mutex domain_acl_lock;
 
+#include <linux/dcache.h>
+extern spinlock_t vfsmount_lock;
+
+#ifdef D_PATH_DISCONNECT
+
+static inline void ccs_realpath_lock(void)
+{
+	spin_lock(&vfsmount_lock);
+	spin_lock(&dcache_lock);
+}
+static inline void ccs_realpath_unlock(void)
+{
+	spin_unlock(&dcache_lock);
+	spin_unlock(&vfsmount_lock);
+}
+
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 0)
+
+static inline void ccs_realpath_lock(void)
+{
+	spin_lock(&dcache_lock);
+	spin_lock(&vfsmount_lock);
+}
+static inline void ccs_realpath_unlock(void)
+{
+	spin_unlock(&vfsmount_lock);
+	spin_unlock(&dcache_lock);
+}
+
+#else
+
+static inline void ccs_realpath_lock(void)
+{
+	spin_lock(&dcache_lock);
+}
+static inline void ccs_realpath_unlock(void)
+{
+	spin_unlock(&dcache_lock);
+}
+
+#endif
+
 #endif
